AppLinksPlatform class abstract

The interface that implementations of app_links must implement.

Platform implementations should extend this class rather than implement it as app_links does not consider newly added methods to be breaking changes. Extending this class ensures that the subclass will get the default implementation, while platform implementations that merely implement the interface will be broken by newly added AppLinksPlatform functions.

Inheritance
  • Object
  • PlatformInterface
  • AppLinksPlatform
Implementers

Constructors

AppLinksPlatform()
Constructs a AppLinksPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringLinkStream Stream<String>
Stream for receiving all incoming URI events as String.
no setter
uriLinkStream Stream<Uri>
Stream for receiving all incoming URI events as Uri.
no setter

Methods

Gets the initial/first link received.
getInitialLinkString() Future<String?>
Gets the initial/first link received.
Gets the latest link received.
getLatestLinkString() Future<String?>
Gets the latest link received.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppLinksPlatform
The default instance of AppLinksPlatform to use.
getter/setter pair